<div align="center">

# purekit

[![GitHub](https://img.shields.io/badge/github-code-blue?label=GitHub)](https://github.com/oyghen/purekit)
[![PyPI](https://img.shields.io/pypi/v/purekit?label=PyPI)](https://pypi.org/project/purekit)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://github.com/oyghen/purekit/blob/main/LICENSE)
[![CI](https://github.com/oyghen/purekit/actions/workflows/ci.yml/badge.svg?branch=main)](https://github.com/oyghen/purekit/actions/workflows/ci.yml)

</div>

```shell
pip install purekit
```
